@@ -403,7 +403,7 @@ def apply_patch(original, patchfile, reverse=False, fuzz=2):
         if fuzz != 2: cmdline.append("--fuzz=%d" % fuzz)
         cmdline += [result.name, patchfile.name]
 
-        exitcode = subprocess.call(cmdline, stdout=_devnull, stderr=_devnull)
+        exitcode = subprocess.call(cmdline)
         if exitcode != 0:
             raise PatchApplyError("Failed to apply patch (exitcode %d)." % exitcode)
 
